package es.carlosgarcia.widget;

import android.content.Context;
import android.util.AttributeSet;
import android.widget.LinearLayout;
import android.widget.SeekBar;
import android.widget.SeekBar.OnSeekBarChangeListener;
import android.widget.TextView;

/**
 * Control personalizado que representa una barra de progreso con un título con:
 * @param min: 		Valor mánimo
 * @param progress: Valor actual
 * @param text:		Título mostrado
 * @author Carlos García. http://www.carlos-garcia.es
 */
public class SeekBarCustom extends LinearLayout implements OnSeekBarChangeListener {
	private static final String NS 		 = "http://schemas.android.com/apk/res/android";
	private static final String PROGRESS = "progress";
	private static final String MAX		 = "max";
	private static final String TEXT	 = "text";
	
	private int		 resCode;
	private SeekBar  bar;
	private TextView caption;
	
	public SeekBarCustom(Context context, AttributeSet attrs) {
		super(context, attrs);
		this.initUI(attrs);
	}
	
	/**
	 * Inizializamos el control leyendo los atributos personalizados max, progress y text
	 * @param attrs
	 */
	private void initUI(AttributeSet attrs){
		this.caption = new TextView(this.getContext());
		this.bar   	 = new SeekBar(this.getContext());
		this.resCode = attrs.getAttributeResourceValue(NS, TEXT, 0);
		
		this.setOrientation(LinearLayout.VERTICAL);
		this.addView(caption);
		this.addView(bar);

		int progress = attrs.getAttributeUnsignedIntValue(NS, PROGRESS, 1);
		caption.setText(getResources().getString(resCode, progress));
		
		bar.setMax(attrs.getAttributeUnsignedIntValue(NS, MAX, 100) + 1);
		bar.setProgress(progress);
		
		
		bar.setOnSeekBarChangeListener(this);
	}

	/**
	 * Permite al usuario establecer el valor, validamos que sea un valor correcto.
	 */
	public void setProgress(int p){
		if ((p < 0) || (p > bar.getMax())){
			throw new IllegalArgumentException();
		}
		bar.setProgress(p);
	}

	public int getProgress(){
		return bar.getProgress();
	}	
	
	/**
	 * Indica si el usuario ha seleccionado algún valor
	 */
	public boolean isValueSelected(){
		return (bar.getProgress() > 0);
	}
	
	/**
	 * Cambiamos el título del control cuando el usuario mueve el SeekBar.
	 */
	@Override
	public void onProgressChanged(SeekBar seekBar, int progress, boolean fromUser) {
		caption.setText(getResources().getString(resCode, progress));
	}

	@Override
	public void onStartTrackingTouch(SeekBar seekBar) {}

	@Override
	public void onStopTrackingTouch(SeekBar seekBar) {}
}
